@@ -1,14 +1,10 @@
 package Set::IntervalTree;
 
-# ABSTRACT: Perform range-based lookups on sets of ranges
-
 use 5.006001;
 use strict;
 use warnings;
 use Carp;
 
-our $VERSION = '0.11_01'; # TRIAL VERSION
-
 require Exporter;
 use AutoLoader;
 
@@ -31,6 +27,7 @@ our @EXPORT = qw(
 	
 );
 
+our $VERSION = '0.01';
 
 sub AUTOLOAD {
     # This AUTOLOAD is used to 'autoload' constants from the constant()
@@ -39,7 +36,7 @@ sub AUTOLOAD {
     my $constname;
     our $AUTOLOAD;
     ($constname = $AUTOLOAD) =~ s/.*:://;
-    croak "&Set::IntervalTree::constant not defined!" if $constname eq 'constant';
+    croak "&Set::IntervalTree::constant not defined" if $constname eq 'constant';
     my ($error, $val) = constant($constname);
     if ($error) { croak $error; }
     {
@@ -63,20 +60,12 @@ XSLoader::load('Set::IntervalTree', $VERSION);
 # Autoload methods go after =cut, and are processed by the autosplit program.
 
 1;
-
 __END__
-
-=pod
-
-=encoding UTF-8
+# Below is stub documentation for your module. You'd better edit it!
 
 =head1 NAME
 
-Set::IntervalTree - Perform range-based lookups on sets of ranges
-
-=head1 VERSION
-
-version 0.11_01
+Set::IntervalTree - Perform range-based lookups on sets of ranges.
 
 =head1 SYNOPSIS
 
@@ -88,23 +77,13 @@ version 0.11_01
   $tree->insert($some_obj,1000,1100);
 
   my $results = $tree->fetch(400,800);
-  my $window = $tree->fetch_window(100,200);
   print scalar(@$results)." intervals found.\n";
 
-  # remove only items overlapping location 100..200 with values 
-  # less than 100;
-  my $removed = $tree->remove(100,200 sub {
-    my ($item, $low, $high) = @_;
-    return $item < 100;
-  });
-
 =head1 DESCRIPTION
 
 Set::IntervalTree uses Interval Trees to store and efficiently 
 look up ranges using a range-based lookup.
 
-All intervals are half-open, i.e. [1,3), [2,6), etc.
-
 =head1 EXPORTS
 
 Nothing.
@@ -124,7 +103,7 @@ $tree->insert($object, $low, $high);
   $low is the lower bound of the range.
   $high is the upper bound of the range.
 
-  Ranges are represented as half-closed integer intervals.
+  Ranges are represented as both-ends closed intervals.
 
 my $results = $tree->fetch($low, $high)
 
@@ -134,50 +113,10 @@ my $results = $tree->fetch($low, $high)
   $low is the lower bound of the region to query.
   $high is the upper bound of the region to query.
 
-my $results = $tree->fetch_window($low, $high)
+=head1 Limitations
 
-  Return an arrayref of perl objects whose ranges are completely contained
-  witin the specified range.
-
-  $low is the lower bound of the region to query.
-  $high is the upper bound of the region to query.
-
-my $nearest_up = $tree->fetch_nearest_up($query)
-
-  Search for the closest interval in upstream that does not contain the query
-  and returns the perl object associated with it.
-
-  $query is the position to use for the search
-
-my $nearest_down = $tree->fetch_nearest_down($query)
-
-  Search for the closest interval in downstream that does not contain the query
-  and returns the perl object associated with it.
-
-  $query is the position to use for the search
-
-my $removed = $tree->remove($low, $high [, optional \&coderef]);
-
-  Remove items in the tree that overlap the region from $low to $high. 
-  A coderef can be passed in as an optional third argument for filtering
-  what is removed. The coderef receives the stored item, the low point,
-  and the high point as its arguments. If the result value of the coderef
-  is true, the item is removed, otherwise the item remains in the tree.
-
-  Returns the list of removed items.
-
-my $removed = $tree->remove_window($low, $high [, optional \&coderef]);
-
-  Remove items in the tree that are contained within the region from $low
-  to $high.  A coderef can be passed in as an optional third argument
-  for filtering what is removed. The coderef receives the stored item,
-  the low point, and the high point as its arguments. If the result
-  value of the coderef is true, the item is removed, otherwise the item
-  remains in the tree.
-
-  Returns the list of removed items.
-
-=head1 LIMITATIONS
+I still haven't implemented a $tree->remove() method to remove ranges 
+from a tree.
 
 A $tree->print() serialization method might be useful for debugging.
 
@@ -186,25 +125,17 @@ A $tree->print() serialization method might be useful for debugging.
 The source code for this module contains a reusable template-based 
 C++ header for Interval trees that might be useful.
 
-=head1 AUTHORS
+=head1 AUTHOR
 
-=over 4
-
-=item *
-
-Benjamin Booth <benbooth@cpan.org>
-
-=item *
-
-Stephan Loyd <sloyd@cpan.org>
-
-=back
+Ben Booth, E<lt>bbooth@E<gt>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2012 by Benjamin Booth.
+Copyright (C) 2010 by Ben Booth
+
+This library is free software; you can redistribute it and/or modify
+it under the same terms as Perl itself, either Perl version 5.10.1 or,
+at your option, any later version of Perl 5 you may have available.
 
-This is free software; you can redistribute it and/or modify it under
-the same terms as the Perl 5 programming language system itself.
 
 =cut
